#! /bin/sh
LANG=en_US.utf8
LC_ALL=en_US.utf8
unameout="$(uname -s)"
year=`date --date "0 day ago" "+%Y"`
month=`date --date "0 day ago" "+%m"`
day=`date --date "0 day ago" "+%d"`

idate=`date --date "0 day ago" "+%Y%m%d"`
fdate=`date --date "-5 day ago" "+%Y%m%d"`

rm gulf*
rm *.nc
rm *.ctl

rm figdir/*.png
rm animdir/*.gif
rm Snldir/*.png

nx=201
ny=131

lonw1=-10.0
lone1=10.0
lats1=-5.0
latn1=8.0

lonw2=-5.0
lone2=5.0
lats2=-2.0
latn2=6.0

blon1=0.0
blat1=0.0 
bstn1='Test_Ghana1'

blon2=-1.0
blat2=4.5
bstn2='Test_Ghana2'


cp grid/gulf.bot .
cp grid/gulf.obstr .
cp grid/gulf.mask .

cat>ww3_grid.inp<<eofinp
$ -------------------------------------------------------------------- $
$ WAVEWATCH III Grid preprocessor input file                           $
$ -------------------------------------------------------------------- $
  'Gulf         '
$
 1.1 0.06623 29 24 0.5
 F T T T F T
$
 900.  950.  900.  300.
$
 &MISC FLAGTR = 4 /
$ &SIN4 BETAMAX = 1.33 /
END OF NAMELISTS
$
 'RECT' T 'NONE'
 ${nx} ${ny}
6.00    6.00   60.00
 ${lonw1} ${lats1} 1.00
$ Bottom Bathymetry
-0.10   2.50  40  0.001000  1  1 '(....)'  NAME  'gulf.bot'
$ Sub-grid information
50  0.010000  1  1  '(....)'  NAME  'gulf.obstr'
$ Mask Information
60  1  1  '(....)'  NAME  'gulf.mask'
$
 0. 0. 0. 0. 0
$ -------------------------------------------------------------------- $
$ End of input file                                                    $
$ -------------------------------------------------------------------- $
eofinp

cat>ww3_strt.inp<<eofinp
$ -------------------------------------------------------------------- $
$ WAVEWATCH III Initial conditions input file                          $
$ ---------------------------------------------------------------------$
    3
$ -------------------------------------------------------------------- $
$ End of input file                                                    $
$ -------------------------------------------------------------------- $
eofinp

cat>ww3_prnc.inp<<eofinp
$ -------------------------------------------------------------------- $
$ WAVEWATCH III Field preprocessor input file                          $

$
  'WND' 'LL' T T
$
$ lon lat
  longitude latitude
$
$ Variables to use --------------------------------------------------- $
$
$  u v
   UGRD_10maboveground VGRD_10maboveground
$
  'gefs.uv.10m.wnd.${idate}.nc'
$ -------------------------------------------------------------------- 
$ End of input file                                                    
$ -------------------------------------------------------------------- $
eofinp

cat>ww3_shel.inp<<eofinp
$ --------------------------------------------------------------------
$ WAVEWATCH III shell input file
$ -------------------------------------------------------------------- $
   F F     Water levels
   F F     Currents
   T F     Winds
   F       Ice concentrations
   F       Assimilation data : Mean parameters
   F       Assimilation data : 1-D spectra
   F       Assimilation data : 2-D spectra.
$
   ${idate} 000000
   ${fdate} 000000
$
   1
$
   ${idate} 000000  10800  ${fdate} 000000
   N
   WND HS FP DP
   ${idate} 000000  10800  ${fdate} 000000
    ${blon1} ${blat1} '${bstn1}    '
    ${blon2} ${blat2} '${bstn2}    '
     0.0   0.0 'STOPSTRING'
   ${idate} 000000     0  ${fdate} 000000
   ${idate} 000000     0  ${fdate} 000000
   ${idate} 000000     0  ${fdate} 000000
   ${idate} 000000     0  ${fdate} 000000
$
   'STP'
$ --------------------------------------------------------------------
$ End of input file
$ --------------------------------------------------------------------
eofinp

cat>gx_outf.inp<<eofinp
$ -------------------------------------------------------------------- $
$ WAVEWATCH III Grid output post-processing ( GrADS )                  $
$ ------------------------------------------------------------------- $
$ Time, time increment and number of outputs.                          $
$
  ${idate} 000000  10800. 41
$
  N
 WND HS FP DP
$
$ ----------------------------------------------------------------$
$
  0 999 0 999  T T
$
$ -------------------------------------------------------------------- $
$ End of input file                                                    $
$ -------------------------------------------------------------------- $
eofinp

cat>Ghana_map1.gs<<eofgs
*
* map_Ghana.gs  : GrADS script for Ghana
* ----------------------------------------------------------------
*           Scripts used :
*              colorset.gs : Sets up shading colors
*
* General set up

  t1 =   1
  tn =  41
  ts =   1

  plot_map = 'yes'
  plot_act = 'yes'
  plot_msk = 'yes'
  plot_hs  = 'yes' ; hs_type = -1
  plot_con = 'yes'
  plot_dir = 'yes'
  plot_wnd = 'yes'
  plot_bys = 'yes'
  plot_lab = 'yes'
  pan = '(a) .....'

  if ( hs_type = -1 )
    hspar = 'hs'
    thpar = 'fp'
  endif
  if ( hs_type = 0 )
    hspar = 'phs00'
    thpar = 'pth00'
  endif
  if ( hs_type = 1 )
    hspar = 'phs01'
    thpar = 'pth01'
  endif
  if ( hs_type = 2 )
    hspar = 'phs02' 
    thpar = 'pth02'
  endif
  if ( hs_type = 3 )
    hspar = 'phs03' 
    thpar = 'pth03'
  endif
  if ( hs_type = 4 )
    hspar = 'phs04' 
    thpar = 'pth04'
  endif
  if ( hs_type = 5 )
    hspar = 'phs05' 
    thpar = 'pth05'
  endif

  xpl = 1.0
  xph = 7.5
  ypl = 2.0
  yph = 9.0

  xml =   ${lonw1}
  xmh =   ${lone1}
  yml =   ${lats1}
  ymh =   ${latn1}

  wsc1 = 10.0

 clevs = '0.20 0.40 0.60 0.80 1.00 1.20 1.40 1.60 1.80 2.00 2.20 2.40 2.60 2.80 3.00'
 ccols = '31  33  35  42  44  46  21  22  23  24  25  26  27 28 29 58'

  if ( plot_act = 'yes' )
    col_act = 69
  else
    col_act = 70
  endif
  
  if ( plot_msk = 'yes' )
    col_msk = 71
  else
    col_msk = 70
  endif

  strsiz = ( xph - xpl ) * 0.03

  pdx = ( xph - xpl ) * 0.0075
  strsiz2 = ( xph - xpl ) * 0.025

  'set display color white'
  'c'
  'run define_colors.gs'

  gdate="yyyy/mm/dd"
  '!date -u "+%Y/%m/%d" > tmp_grads_gdate'
  result = read (tmp_grads_gdate)
  gdate = sublin(result,2)
  '!rm -f tmp_grads_gdate'

* ID output to screen

  say ' '
  say '----------------------'
  say '*** Running map.gs ***'
  say '----------------------'
  say ' ' 
  say 'Number of ouptput points : ' nr
  say 'Time steps from ' t1 ' through ' tn ' with step ' ts

* Loop over time steps

  'open ww3'

  i = 1
  t = t1

  '!rm -f plot.grads.*'

  while ( t <= tn )
    'set t ' t

    'query time'
    gradsdate = subwrd(result,3)
    test = substr ( gradsdate, 3, 1 )
    if ( test='Z' )
      year = substr ( gradsdate, 9, 4 )
      mnth = substr ( gradsdate, 6, 3 )
      day  = substr ( gradsdate, 4, 2 )
      hour = substr ( gradsdate, 1, 2 )
      min  = '00'
    else
      year = substr ( gradsdate, 12, 4 )
        mnth = substr ( gradsdate, 9, 3 )
      day  = substr ( gradsdate, 7, 2 )
      hour = substr ( gradsdate, 1, 2 )
      min  = substr ( gradsdate, 4, 2 )
    endif

    month= '??'
    if (mnth='JAN'); month= '01'; endif;
    if (mnth='FEB'); month= '02'; endif;
    if (mnth='MAR'); month= '03'; endif;
    if (mnth='APR'); month= '04'; endif;
    if (mnth='MAY'); month= '05'; endif;
    if (mnth='JUN'); month= '06'; endif;
    if (mnth='JUL'); month= '07'; endif;
    if (mnth='AUG'); month= '08'; endif;
    if (mnth='SEP'); month= '09'; endif;
    if (mnth='OCT'); month= '10'; endif;
    if (mnth='NOV'); month= '11'; endif;
    if (mnth='DEC'); month= '12'; endif;

    vdate = year '/' month '/' day ' ' hour 'z'

    say '   processing time step ' t ', time is ' vdate

* Basic plot set up

    'clear'
    'set grads off'
    'set lon ' xml ' ' xmh
    'set lat ' yml ' ' ymh
    'set xlint 5'
    'set ylint 5'
    'set grid on 3 60'
     'set mpdset hires'
     'set parea  0.5 9.9 0.5 7.5'

* Plot Ghana grid ------------------------------------------------ *

* Plot map

    if ( plot_map = 'yes' )
      'set gxout grfill'
      'set clevs -4.5 -3.5 -2.5 -1.5 -0.5  0.5 1.5'
      'set ccols 60  ' col_msk '  67   68   63   0   0  ' col_act
      'd map'
    endif

* Plot Hs

    if ( plot_hs = 'yes' )
      'set gxout shaded'
      'set clevs ' clevs
      'set ccols ' ccols
      'd ' hspar
      'run cbarn'
  
      if ( plot_con = 'yes' )
        'set gxout contour'
        'set cthick 1'
        'set ccolor 60'
        'set clevs ' clevs
        'set clab off'
        'd ' hspar
      endif

    endif

* Plot directions

    if ( plot_dir = 'yes' )
      'set gxout vector'
      'set cthick 6'
      'set arrscl 0.25'
*      'set arrlab off'
      'set ccolor 1'
      'd skip(cos(dp)*1.944,8,8);sin(dp)*1.944'
    endif

* Plot wind

    if ( plot_wnd = 'yes' )
      'set gxout barb'
      'set cthick 6'
      'set arrscl 0.25 ' wsc1
      'set ccolor 2'
      'd skip(uwnd*1.944, 8,8);vwnd*1.944'
    endif

* Panel and date marker

    if ( plot_lab = 'yes' )
      'set strsiz ' strsiz
      'set strsiz ' strsiz
      'set string 0 l'
      'draw string 1.25 10.75 ' vdate
    endif
 
* Legend
    'set string 1 c 6'
    'set strsiz ' strsiz
    'draw string 5.5 8.3 Wave Watch III Forecast 'vdate
    'draw string 5.5 8.0 Gulf / Ghana sig. wave height (m)'
     'set strsiz 0.13'
'draw string 5.5 7.7 Wave (black) & Wind Speed (red), Knots'
* Finalize
'printim plot_heightNwind_'t'.png'
*    pull OK
    t = t + ts
    i = i + 1
  endwhile

* End of loop over time steps

  say ' '
  say '----------------------'
  say '*** End of map.gs  ***'
  say '----------------------'
  say ' ' 
  'quit'
eofgs

cat> Ghana_map2.gs<<eofGS
*
* map_Ghana.gs  : GrADS script for Ghana
* ----------------------------------------------------------------
*           Scripts used :
*              colorset.gs : Sets up shading colors
*
* General set up

  t1 =   1
  tn =  41
  ts =   1

  plot_map = 'yes'
  plot_act = 'yes'
  plot_msk = 'yes'
  plot_hs  = 'yes' ; hs_type = -1
  plot_con = 'yes'
  plot_dir = 'yes'
  plot_wnd = 'yes'
  plot_bys = 'yes'
  plot_lab = 'yes'
  pan = '(a) .....'

  if ( hs_type = -1 )
    hspar = 'hs'
    thpar = 'fp'
  endif
  if ( hs_type = 0 )
    hspar = 'phs00'
    thpar = 'pth00'
  endif
  if ( hs_type = 1 )
    hspar = 'phs01'
    thpar = 'pth01'
  endif
  if ( hs_type = 2 )
    hspar = 'phs02' 
    thpar = 'pth02'
  endif
  if ( hs_type = 3 )
    hspar = 'phs03' 
    thpar = 'pth03'
  endif
  if ( hs_type = 4 )
    hspar = 'phs04' 
    thpar = 'pth04'
  endif
  if ( hs_type = 5 )
    hspar = 'phs05' 
    thpar = 'pth05'
  endif

  xpl = 0.5
  xph = 10.5
  ypl = 3.0
  yph = 8.0

  xml =   $lonw2
  xmh =   $lone2
  yml =   $lats2
  ymh =   $latn2

  wsc1 = 10.0

 clevs = '0.20 0.40 0.60 0.80 1.00 1.20 1.40 1.60 1.80 2.00 2.20 2.40 2.60 2.80 3.00'
  ccols = '31  33  35  42  44  46  21  22  23  24  25  26  27 28 29 58'

  if ( plot_act = 'yes' )
    col_act = 69
  else
    col_act = 70
  endif
  
  if ( plot_msk = 'yes' )
    col_msk = 71
  else
    col_msk = 70
  endif

  strsiz = ( xph - xpl ) * 0.03

  pdx = ( xph - xpl ) * 0.0075
  strsiz2 = ( xph - xpl ) * 0.025

  'set display color white'
  'c'
  'run define_colors.gs'

  gdate="yyyy/mm/dd"
  '!date -u "+%Y/%m/%d" > tmp_grads_gdate'
  result = read (tmp_grads_gdate)
  gdate = sublin(result,2)
  '!rm -f tmp_grads_gdate'

* Set buoy data hardcoded

  nr = 2
  xx1 =  0.0
  yy1 =  0.0
  s1 = Test_Ghana1

  xx2 =  -1.0
  yy2 =  4.5
  s2 = Test_Ghana2

* ID output to screen

  say ' '
  say '----------------------'
  say '*** Running map.gs ***'
  say '----------------------'
  say ' ' 
  say 'Number of ouptput points : ' nr
  say 'Time steps from ' t1 ' through ' tn ' with step ' ts

* Loop over time steps

  'open ww3'

  i = 1
  t = t1

  '!rm -f plot.grads.*'

  while ( t <= tn )
    'set t ' t

    'query time'
    gradsdate = subwrd(result,3)
    test = substr ( gradsdate, 3, 1 )
    if ( test='Z' )
      year = substr ( gradsdate, 9, 4 )
      mnth = substr ( gradsdate, 6, 3 )
      day  = substr ( gradsdate, 4, 2 )
      hour = substr ( gradsdate, 1, 2 )
      min  = '00'
    else
      year = substr ( gradsdate, 12, 4 )
        mnth = substr ( gradsdate, 9, 3 )
      day  = substr ( gradsdate, 7, 2 )
      hour = substr ( gradsdate, 1, 2 )
      min  = substr ( gradsdate, 4, 2 )
    endif

    month= '??'
    if (mnth='JAN'); month= '01'; endif;
    if (mnth='FEB'); month= '02'; endif;
    if (mnth='MAR'); month= '03'; endif;
    if (mnth='APR'); month= '04'; endif;
    if (mnth='MAY'); month= '05'; endif;
    if (mnth='JUN'); month= '06'; endif;
    if (mnth='JUL'); month= '07'; endif;
    if (mnth='AUG'); month= '08'; endif;
    if (mnth='SEP'); month= '09'; endif;
    if (mnth='OCT'); month= '10'; endif;
    if (mnth='NOV'); month= '11'; endif;
    if (mnth='DEC'); month= '12'; endif;

*   vdate = year '/' month '/' day ' ' hour ':' min 'z'
    vdate = year '/' month '/' day ' ' hour 'z'
*   vdate = pan ' ' hour ':' min 'z'
*   vdate = hour ':' min 'z'

    say '   processing time step ' t ', time is ' vdate

* Basic plot set up

*    'enable print plot.grads.' t
    'clear'
    'set grads off'
    'set lon ' xml ' ' xmh
    'set lat ' yml ' ' ymh
    'set xlint 2'
    'set ylint 2'
    'set grid on 3 60'
     'set mpdset hires'
     'set parea  0.5 9.9 0.5 7.5'

* Plot Ghana grid ------------------------------------------------ *

* Plot map

    if ( plot_map = 'yes' )
      'set gxout grfill'
      'set clevs -4.5 -3.5 -2.5 -1.5 -0.5  0.5 1.5'
      'set ccols 60  ' col_msk '  67   68   63   0   0  ' col_act
      'd map'
    endif

* Plot Hs

    if ( plot_hs = 'yes' )
      'set gxout shaded'
      'set clevs ' clevs
      'set ccols ' ccols
      'd ' hspar
      'run cbarn'
  
      if ( plot_con = 'yes' )
        'set gxout contour'
        'set cthick 1'
        'set ccolor 60'
        'set clevs ' clevs
        'set clab off'
        'd ' hspar
      endif

    endif

* Plot directions

    if ( plot_dir = 'yes' )
      'set gxout vector'
      'set cthick 6'
      'set arrscl 0.25'
      'set ccolor 1'
      'd skip(cos(dp)*1.944,6,6);sin(dp)*1.944'
    endif

* Plot wind

    if ( plot_wnd = 'yes' )
      'set gxout barb'
      'set cthick 6'
      'set arrscl 0.25 ' wsc1
*      'set arrlab off'
      'set ccolor 2'
      'd skip(uwnd*1.944, 6,6);vwnd*1.944'
    endif

* Plot output locations -------------------------------------------------- *

'q w2xy 'xx1' 'yy1''; tt=sublin(result,1); x1=subwrd(tt,3); y1=subwrd(tt,6)
say x1 ' ' y1 ' ' s1
'set line 1 2 6'
    'draw mark 3 'x1' 'y1' 0.25'
'set string 1 c 6'
'set strsiz 0.25'
'draw string 'x1+1.5' 'y1' 's1''

'q w2xy 'xx2' 'yy2''; tt=sublin(result,1); x2=subwrd(tt,3); y2=subwrd(tt,6)
say x2 ' ' y2 ' ' s2
'set line 1 2 6'
    'draw mark 3 'x2' 'y2' 0.25'
'set string 1 c 6'
'set strsiz 0.25'
'draw string 'x2+1.5' 'y2' 's2''

* Panel and date marker

    if ( plot_lab = 'yes' )
      'set strsiz ' strsiz
      'set strsiz ' strsiz
      'set string 0 l'
      'draw string 1.25 10.75 ' vdate
    endif
 
* Legend
    'set string 1 c 6'
    'set strsiz 0.2'
    'draw string 5.5 8.3 Wave Watch III Forecast 'vdate
    'draw string 5.5 8.0 Gulf / Ghana sig. wave height (m)'
     'set strsiz 0.13'
'draw string 5.5 7.7 Wave (black) & Wind Speed (red), Knots'
* Finalize
'printim plot_heightNwind_'t'.png'
*    pull OK
    t = t + ts
    i = i + 1
  endwhile

* End of loop over time steps

  say ' '
  say '----------------------'
  say '*** End of map.gs  ***'
  say '----------------------'
  say ' ' 
  'quit'
eofGS


cat>anim1.txt<<eoftxt
plot_heightNwind_1.png
plot_heightNwind_2.png
plot_heightNwind_3.png
plot_heightNwind_4.png
plot_heightNwind_5.png
plot_heightNwind_6.png
plot_heightNwind_7.png
plot_heightNwind_8.png
plot_heightNwind_9.png
plot_heightNwind_10.png
plot_heightNwind_11.png
plot_heightNwind_12.png
plot_heightNwind_13.png
plot_heightNwind_14.png
plot_heightNwind_15.png
plot_heightNwind_16.png
plot_heightNwind_17.png
plot_heightNwind_18.png
plot_heightNwind_19.png
plot_heightNwind_20.png
plot_heightNwind_21.png
plot_heightNwind_22.png
plot_heightNwind_23.png
plot_heightNwind_24.png
plot_heightNwind_25.png
plot_heightNwind_26.png
plot_heightNwind_27.png
plot_heightNwind_28.png
plot_heightNwind_29.png
plot_heightNwind_30.png
plot_heightNwind_31.png
plot_heightNwind_32.png
plot_heightNwind_33.png
plot_heightNwind_34.png
plot_heightNwind_35.png
plot_heightNwind_36.png
plot_heightNwind_37.png
plot_heightNwind_38.png
plot_heightNwind_39.png
plot_heightNwind_40.png
eoftxt

cat>anim2.txt<<eoftxt
sterms_plot_1.png
sterms_plot_2.png
sterms_plot_3.png
sterms_plot_4.png
sterms_plot_5.png
sterms_plot_6.png
sterms_plot_7.png
sterms_plot_8.png
sterms_plot_9.png
sterms_plot_10.png
sterms_plot_11.png
sterms_plot_12.png
sterms_plot_13.png
sterms_plot_14.png
sterms_plot_15.png
sterms_plot_16.png
sterms_plot_17.png
sterms_plot_18.png
sterms_plot_19.png
sterms_plot_20.png
sterms_plot_21.png
sterms_plot_22.png
sterms_plot_23.png
sterms_plot_24.png
sterms_plot_25.png
sterms_plot_26.png
sterms_plot_27.png
sterms_plot_28.png
sterms_plot_29.png
sterms_plot_30.png
sterms_plot_31.png
sterms_plot_32.png
sterms_plot_33.png
sterms_plot_34.png
sterms_plot_35.png
sterms_plot_36.png
sterms_plot_37.png
sterms_plot_38.png
sterms_plot_39.png
sterms_plot_40.png
eoftxt

rm gefs.t00z.pgrb2.0p50*
for ff in 000 003 006 009 012 015 018 021 024 027 030 033 036 039 042 045 048 051 054 057 060 063 066 069 072 075 078 081 084 087 090 093 096 099 102 105 108 111 114 117 120; do

URL="https://nomads.ncep.noaa.gov/pub/data/nccf/com/gens/prod/gefs.${year}${month}${day}/00/atmos/pgrb2ap5/geavg.t00z.pgrb2a.0p50.f${ff}"
wget $URL -O gefs.t00z.pgrb2.0p50.f0${ff}
wgrib2 gefs.t00z.pgrb2.0p50.f0${ff} -s | egrep '(:UGRD:10 m above ground:|:VGRD:10 m above ground:)' | wgrib2 -i gefs.t00z.pgrb2.0p50.f0${ff} -grib gefs_${ff}.grb
done

cat  gefs_000.grb gefs_003.grb gefs_006.grb gefs_009.grb gefs_012.grb gefs_015.grb gefs_018.grb gefs_021.grb gefs_024.grb gefs_027.grb gefs_030.grb gefs_033.grb gefs_036.grb gefs_039.grb gefs_042.grb gefs_045.grb gefs_048.grb gefs_051.grb gefs_054.grb gefs_057.grb gefs_060.grb gefs_063.grb gefs_066.grb gefs_069.grb gefs_072.grb gefs_075.grb gefs_078.grb gefs_081.grb gefs_084.grb gefs_087.grb gefs_090.grb gefs_093.grb gefs_096.grb gefs_099.grb gefs_102.grb gefs_105.grb gefs_108.grb gefs_111.grb gefs_114.grb gefs_117.grb gefs_120.grb > gefs_all.grb

wgrib2 gefs_all.grb -netcdf gefs.uv.10m.wnd.${year}${month}${day}.nc

rm gefs_???.grb gefs.t* gefs_all.grb

ww3_grid
ww3_strt
ww3_prnc
ww3_shel
gx_outf

cdate=`date --date "0 day ago" "+%d%b%Y"`

cat>ww3.ctl<<eofCTL
DSET      ww3.grads
TITLE     WAVEWATCH III gridded data
OPTIONS   sequential
OPTIONS   big_endian
UNDEF      -999.9
XDEF      ${nx}  LINEAR    ${lonw1}     0.10000
YDEF      ${ny}  LINEAR    ${lats1}     0.10000
ZDEF        1  LINEAR   1000.00000     1.00000
TDEF       41  LINEAR     00:00Z${cdate}   3HR
VARS        6
MAP     0  99  grid use map
uwnd    0  99  Wind U (m/s)
vwnd    0  99  Wind V (m/s)
hs      0  99  Wave height (m)
fp      0  99  Peak Freq. (Hz)
dp      0  99  Peak Dir. (rad)
ENDVARS
eofCTL

/usr/local/bin/grads -blc Ghana_map1.gs
convert -delay 60 @anim1.txt Gha_big_heightNwind_${idate}_IC.gif

/usr/local/bin/grads -blc Ghana_map2.gs
convert -delay 60 @anim1.txt Gha_small_heightNwind_${idate}_IC.gif

for loc in 1 2; do

if [ $loc = 1 ]; then stn=$bstn1 ; fi	
if [ $loc = 2 ]; then stn=$bstn2 ; fi

cat>gx_outp.inp<<eofinp
$ -------------------------------------------------------------------- $
$ WAVEWATCH III Point output post-processing ( GrADS )                  $
$ ------------------------------------------------------------------- $
$ Time, time increment and number of outputs.                          $
$
  ${idate} 000000  10800. 41
$
 ${loc}
 -1
$
 T T T T T T T
$
$ -------------------------------------------------------------------- $
$ End of input file                                                    $
$ -------------------------------------------------------------------- $
eofinp

gx_outp

/usr/local/bin/grads -bpc 1source.gs
/usr/local/bin/grads -bpc source.gs

mv Snl_plot_1.png Snl_${stn}_1.png
mv Snl_plot_2.png Snl_${stn}_2.png
mv Snl_plot_3.png Snl_${stn}_3.png
mv Snl_plot_4.png Snl_${stn}_4.png
mv Snl_plot_5.png Snl_${stn}_5.png
mv Snl_plot_6.png Snl_${stn}_6.png

convert -delay 60 @anim2.txt ${stn}_sterms_${idate}_IC.gif
done

mv *plot*.png figdir/
mv *.gif animdir/
mv *Snl*.png Snldir/

